@@ -1,10 +1,10 @@
 package My::Group;
 
-# $Id: Group.pm,v 2.0 2002/03/19 04:00:06 lachoy Exp $
+# $Id: Group.pm,v 2.1 2002/04/26 15:35:22 lachoy Exp $
 
 use strict;
 
-$My::Group::VERSION = sprintf("%d.%02d", q$Revision: 2.0 $ =~ /(\d+)\.(\d+)/);
+$My::Group::VERSION = sprintf("%d.%02d", q$Revision: 2.1 $ =~ /(\d+)\.(\d+)/);
 
 my $USER_CLASS = 'My::User';
 
@@ -13,7 +13,7 @@ sub _base_config {
        'group' => {
            class        => 'My::Group',
            isa          => [ 'SPOPS::Secure', 'My::Common' ],
-           rules_from   => [ 'My::DiscoverField' ],
+           rules_from   => [ 'SPOPS::Tool::DBI::DiscoverField' ],
            field_discover => 'yes',
            field        => [],
            id_field     => 'group_id',
